@@ -6,7 +6,7 @@ use Carp;
 use Params::Validate qw(:all);
 use Mic::Assembler;
 
-our $VERSION = '0.000003';
+our $VERSION = '0.000004';
 $VERSION = eval $VERSION;
 
 my $Class_count = 0;
@@ -43,13 +43,13 @@ sub assemble {
     validate(@args, {
         interface => { type => HASHREF | SCALAR },
         implementation => { type => SCALAR },
-        constructor    => { type => HASHREF, optional => 1 },
         name => { type => SCALAR, optional => 1 },
     });
     return $assembler->assemble;
 }
 
 *setup_class = \&assemble;
+*define_class = \&assemble;
 
 sub builder_for {
     my ($class) = @_;
@@ -225,9 +225,9 @@ and "OOP to me means only messaging, local retention and protection and hiding o
 
 =head1 USAGE
 
-=head2 Mic->setup_class(HASHREF)
+=head2 Mic->define_class(HASHREF)
 
-In the simplest scenario in which both interface and implementation are defined in the same file, a class can also be defined by calling the C<setup_class()> class method, with a hashref that
+In the simplest scenario in which both interface and implementation are defined in the same file, a class can also be defined by calling the C<define_class()> class method, with a hashref that
 specifies the class.
 
 The class defined in the SYNOPSIS could also be defined like this
@@ -236,7 +236,7 @@ The class defined in the SYNOPSIS could also be defined like this
 
     use Mic;
 
-    Mic->setup_class({
+    Mic->define_class({
         interface => { 
             object => {
                 add => {},
